@@ -568,7 +568,8 @@ add_inhibitor (GsmInhibitDialog *dialog,
                         GsmClient *client;
                         client = GSM_CLIENT (gsm_store_lookup (dialog->priv->clients, client_id));
                         if (client != NULL) {
-                                freeme = name = gsm_client_get_app_name (client);
+                                freeme = gsm_client_get_app_name (client);
+                                name = freeme;
                         }
                 }
         }
@@ -1001,6 +1002,11 @@ gsm_inhibit_dialog_dispose (GObject *object)
                 dialog->priv->inhibitors = NULL;
         }
 
+        if (dialog->priv->xml != NULL) {
+                g_object_unref (dialog->priv->xml);
+                dialog->priv->xml = NULL;
+        }
+
         G_OBJECT_CLASS (gsm_inhibit_dialog_parent_class)->dispose (object);
 }
 
@@ -1060,7 +1066,7 @@ gsm_inhibit_dialog_init (GsmInhibitDialog *dialog)
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 12);
         gtk_container_set_border_width (GTK_CONTAINER (widget), 12);
         gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-        gtk_window_set_icon_name (GTK_WINDOW (dialog), "gnome-logout");
+        gtk_window_set_icon_name (GTK_WINDOW (dialog), "system-log-out");
         gtk_window_set_title (GTK_WINDOW (dialog), "");
         g_object_set (dialog,
                       "allow-shrink", FALSE,
